==> haskell-knob-0.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-BMqK3hSPOz9mejkvDRIPI
key: knob-0.1.1-BMqK3hSPOz9mejkvDRIPI
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Knob
abi: 142fd384589484f49c3d144d22fdcc32
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/knob-0.1.1
hs-libraries: HSknob-0.1.1-BMqK3hSPOz9mejkvDRIPI
depends:
    base-4.10.0.0 bytestring-0.10.8.2 transformers-0.5.2.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: knob
version: 0.1.1
id: knob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
key: knob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
license: MIT
maintainer: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://john-millikin.com/software/knob/
synopsis: Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.
    .
    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)
category: System
author: John Millikin <jmillikin@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Knob
abi: 4a4c8eb8a957e3a9b62170aace99e713
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/knob-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/knob-0.1.1
hs-libraries: HSknob-0.1.1-4sPosrrSwNF5HdhEVGL5Jj
depends:
    base-4.10.1.0 bytestring-0.10.8.2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html: /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
